<?php
namespace DHLParcelShipping\Service;

class ConfigService
{
    const CONFIG_DOMAIN = 'DHLParcelShipping';
    const CONFIG_KEY_STATUS = 'status';
    const CONFIG_KEY_WEBHOOKURL = 'webhookurl';

    /** @var \Shopware\Components\Plugin\ConfigReader */
    protected $configReader;

    /**
     * @var array
     */
    protected $configData = [];

    /**
     * ConfigService constructor.
     * @param \Shopware\Components\Plugin\ConfigReader $configReader
     */
    public function __construct(\Shopware\Components\Plugin\ConfigReader $configReader)
    {
        $this->configReader = $configReader;
    }

    /**
     * @return string
     */
    public function getWebhookUrl()
    {
        return strval($this->getConfig(self::CONFIG_KEY_WEBHOOKURL));
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return boolval($this->getConfig(self::CONFIG_KEY_STATUS));
    }

    /**
     * @param $key
     * @return mixed|null
     */
    protected function getConfig($key)
    {
        if (empty($this->configData)) {
            try {
                $shop = Shopware()->Shop();
            } catch (ServiceNotFoundException $ex) {
                $shop = null;
            }

            $this->configData = $this->configReader->getByPluginName(self::CONFIG_DOMAIN, $shop);
        }

        if (isset($this->configData[$key])) {
            return $this->configData[$key];
        }

        return null;
    }
}
