<?php
namespace DHLParcelShipping\Service;

use Shopware\Models\Order\Order;

class OrderFormatterService
{
    /**
     * @param Order $order
     * @return array
     */
    public function formatOrderToArray(Order $order)
    {
        $orderArray = $this->objectToArray($order);

        return $orderArray;
    }

    /**
     * @param $object
     * @param int $depth
     * @return array
     */
    public function objectToArray($object, $depth = 0)
    {
        $array = [];
        foreach (get_class_methods($object) as $method) {
            $skipKeys = [
                'password',
                'session_id',
                'password_change_date',
                'encoder_name'
            ];

            if (substr($method, 0, 3) == 'get') {
                $methodName = strtolower(preg_replace('/(?<!^)[A-Z]/', '_$0', substr($method, 3)));

                if (in_array($methodName, $skipKeys)) {
                    continue;
                }

                $value = call_user_func(array($object, $method));

                if (is_object($value)) {
                    if (get_class($value) == 'DateTime') {
                        $array[$methodName] = $value->format(\DateTime::ISO8601);
                    } else {
                        $depthKeys = [
                            'shipping',
                            'billing',
                            'customer',
                            'country',
                            'attribute',
                            'dispatch'
                        ];

                        if ($depth == 2) {
                            continue;
                        }

                        if (get_class($value) == 'Doctrine\ORM\PersistentCollection' && $methodName !== "details") {
                            continue;
                        }

                        // Get products by this order
                        if ($methodName === "details") {
                            $detail = $value->first();
                            while (true) {
                                $array[$methodName][] = $this->objectToArray($detail, ($depth+1));
                                $detail = $value->next();

                                if ($detail == false) {
                                    break;
                                }
                            }
                        }

                        if (in_array($methodName, $depthKeys)) {
                            $array[$methodName] = $this->objectToArray($value, ($depth+1));
                        }
                    }
                } else {
                    $array[$methodName] = $value;
                }
            }
        }

        return $array;
    }
}
