<?php
namespace DHLParcelShipping\Service;

use Shopware\Models\Order\Order;
use GuzzleHttp\Client;

class WebhookService
{
    /**
     * @var Client
     */
    protected $httpClient;

    /**
     * @var ConfigService
     */
    protected $configService;

    /**
     * WebhookService constructor.
     * @param ConfigService $configService
     */
    public function __construct(
        ConfigService $configService,
        OrderFormatterService $orderFormatterService
    ) {
        $this->configService = $configService;
        $this->orderFormatterService = $orderFormatterService;
        $this->httpClient = new Client();
    }

    /**
     * @param Order $order
     */
    public function createDraft(Order $order): void
    {
        $webhookUrl = $this->configService->getWebhookUrl();
        if (empty($webhookUrl)) {
            return;
        }

        $orderFormatted = $this->orderFormatterService->formatOrderToArray($order);

        try {
            $this->httpClient->post($webhookUrl, array(
                'headers'   => [
                    'Content-Type'          => 'application/json',
                    'dhlparcel-connector'   => 'shopware5'
                ],
                'body'                      => json_encode($orderFormatted)
            ));
        } catch (\Exception $e) {
            return;
        }
    }
}
