<?php

namespace DHLParcelShipping\Subscriber;

use DHLParcelShipping\Service\ConfigService;
use DHLParcelShipping\Service\WebhookService;
use Enlight\Event\SubscriberInterface;
use Shopware\Models\Order\Order;

class NewOrderSubscriber implements SubscriberInterface
{
    /**
     * @var ConfigService
     */
    protected $configService;

    /**
     * @var WebhookService
     */
    protected $webhookService;

    /**
     * @var \Doctrine\Common\Persistence\ObjectRepository
     */
    protected $orderRepository;

    /**
     * WebhookService constructor.
     * @param ConfigService $configService
     * @param WebhookService $webhookService
     */
    public function __construct(
        ConfigService $configService,
        WebhookService $webhookService
    ) {
        $this->configService = $configService;
        $this->webhookService = $webhookService;
        $this->orderRepository = Shopware()->Models()->getRepository(Order::class);
    }

    /**
     * @return array
     */
    public static function getSubscribedEvents(): array
    {
        return [
            'Shopware_Modules_Order_SaveOrder_OrderCreated' => 'onOrderCreated'
        ];
    }

    /**
     * @param \Enlight_Event_EventArgs $args
     */
    public function onOrderCreated(\Enlight_Event_EventArgs $args): void
    {
        // Do nothing when webhook is not enabled
        if (!$this->configService->isEnabled()) {
            return;
        }

        /**
         * @var $order Order
         */
        $orderId = $args->get('orderId');
        $order = $this->orderRepository->find($orderId);

        if ($order instanceof Order) {
            $this->webhookService->createDraft($order);
        }
    }
}
